@@ -1,7 +1,7 @@
 '''
 # CDK Construct for S3 Bucket Replication
 
-A CDK Construct for S3 Bucket Replication.  Can handle cross-account replication.
+A CDK Construct for S3 Bucket Replication.  Can handle cross-account replication.  Make sure the source and destination buckets have versioning enabled.
 
 ```
 const sourceBucket = new Bucket(this, 'SourceBucket', {
@@ -46,8 +46,8 @@ class BucketReplication(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        destination_bucket: aws_cdk.aws_s3.Bucket,
-        source_bucket: aws_cdk.aws_s3.Bucket,
+        destination_bucket: aws_cdk.aws_s3.IBucket,
+        source_bucket: aws_cdk.aws_s3.IBucket,
         replication_destination_properties: typing.Optional["ReplicationDestinationPropertyNoBucket"] = None,
         replication_rule_properties: typing.Optional["ReplicationRulePropertyNoDestination"] = None,
     ) -> None:
@@ -66,7 +66,7 @@ class BucketReplication(
             replication_rule_properties=replication_rule_properties,
         )
 
-        jsii.create(BucketReplication, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
 
 @jsii.data_type(
@@ -83,8 +83,8 @@ class BucketReplicationProps:
     def __init__(
         self,
         *,
-        destination_bucket: aws_cdk.aws_s3.Bucket,
-        source_bucket: aws_cdk.aws_s3.Bucket,
+        destination_bucket: aws_cdk.aws_s3.IBucket,
+        source_bucket: aws_cdk.aws_s3.IBucket,
         replication_destination_properties: typing.Optional["ReplicationDestinationPropertyNoBucket"] = None,
         replication_rule_properties: typing.Optional["ReplicationRulePropertyNoDestination"] = None,
     ) -> None:
@@ -108,16 +108,16 @@ class BucketReplicationProps:
             self._values["replication_rule_properties"] = replication_rule_properties
 
     @builtins.property
-    def destination_bucket(self) -> aws_cdk.aws_s3.Bucket:
+    def destination_bucket(self) -> aws_cdk.aws_s3.IBucket:
         result = self._values.get("destination_bucket")
         assert result is not None, "Required property 'destination_bucket' is missing"
-        return typing.cast(aws_cdk.aws_s3.Bucket, result)
+        return typing.cast(aws_cdk.aws_s3.IBucket, result)
 
     @builtins.property
-    def source_bucket(self) -> aws_cdk.aws_s3.Bucket:
+    def source_bucket(self) -> aws_cdk.aws_s3.IBucket:
         result = self._values.get("source_bucket")
         assert result is not None, "Required property 'source_bucket' is missing"
-        return typing.cast(aws_cdk.aws_s3.Bucket, result)
+        return typing.cast(aws_cdk.aws_s3.IBucket, result)
 
     @builtins.property
     def replication_destination_properties(
